@@ -4,7 +4,7 @@ annofabapi.exceptions
 This module contains the set of annofabapi exceptions.
 """
 
-from typing import List
+from typing import List, Optional
 
 from annofabapi.models import OrganizationMemberRole, ProjectMemberRole
 
@@ -25,6 +25,24 @@ class AuthenticationError(AnnofabCliException):
         super().__init__(msg)
 
 
+class UpdatedFileForDownloadingError(AnnofabCliException):
+    """
+    ダウンロード対象ファイルの更新処理のエラー
+    """
+
+    def __init__(self, msg: Optional[str] = None):
+        super().__init__(msg)
+
+
+class DownloadingFileNotFoundError(AnnofabCliException):
+    """
+    ダウンロード対象のファイルが存在しないときのエラー
+    """
+
+    def __init__(self, msg: Optional[str] = None):
+        super().__init__(msg)
+
+
 class AuthorizationError(AnnofabCliException):
     pass
 
